/*
 * Copyright (c) 1991-2024 by STEP Tools Inc. 
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and
 * its documentation is hereby granted, provided that this copyright
 * notice and license appear on all copies of the software.
 * 
 * STEP TOOLS MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE
 * SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT. STEP TOOLS
 * SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A
 * RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS
 * DERIVATIVES.
 *
 * Author: Dave Loffredo (loffredo@steptools.com)
 */

// Prototypes for the tolerance utilities defined in tolerance.cxx


// Apply distance and diameter dimensions to callouts
//
stp_dimensional_location * make_linear_dimension (
    stp_shape_aspect * start_callout,
    stp_shape_aspect * end_callout,
    double val,
    stp_named_unit * u,
    double plus_tol,
    double minus_tol
    );

stp_dimensional_size * make_diameter_dimension (
    stp_shape_aspect * callout,
    double val,
    stp_named_unit * u,
    double plus_tol,
    double minus_tol
    );


// Apply flatness, position, and other tolerances to callouts,
// possibly with associated datums.
//
stp_geometric_tolerance * make_flatness_tol (
    stp_shape_aspect * callout,
    double val,
    stp_named_unit * u
    );

stp_geometric_tolerance_with_datum_reference * make_position_tol (
    stp_shape_aspect * callout,
    double val,
    stp_named_unit * u
    );

stp_geometric_tolerance_with_datum_reference * make_perpendicularity_tol (
    stp_shape_aspect * callout,
    double val,
    stp_named_unit * u
    );


// Define datums and add them to tolerances
//
void add_datum (
    stp_geometric_tolerance_with_datum_reference * tol,
    stp_datum * dat
    );

stp_datum * make_datum (
    const char * name,
    stp_product_definition_shape * pds,
    stp_representation_context * ctx,
    stp_representation_item * face
    );


// Define faces as callouts that will be given tolerances or dims.
//
stp_shape_aspect * make_callout (
    stp_product_definition_shape * pds,
    stp_representation_context * ctx,
    stp_representation_item * face
    );


// Some utilities for making measures and contexts
stp_length_measure_with_unit * make_length_mwu (
    double, stp_named_unit *
    );
stp_measure_representation_item * make_length_repitem (
    double, stp_named_unit *
    );
stp_representation_context * make_simple_rep_context(
    RoseDesign * design
    );


